==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GeographicContourLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicContourLineSeriesDescription } from "./GeographicContourLineSeriesDescription";
/**
 * @hidden
 */
export let GeographicContourLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicContourLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicContourLineSeriesDescriptionMetadata.a == null) {
                GeographicContourLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicContourLineSeriesDescriptionMetadata.c(GeographicContourLineSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicContourLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(GeographicContourLineSeriesDescriptionMetadata.a);
            ValueBrushScaleDescriptionMetadata.d(a);
            ContourValueResolverDescriptionMetadata.d(a);
            TriangulationStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("FillScale", "ExportedType:ValueBrushScale");
            a.item("ActualFillScale", "ExportedType:ValueBrushScale");
            a.item("ValueResolver", "ExportedType:ContourValueResolver");
            a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
        }
        static d(a) {
            GeographicContourLineSeriesDescriptionMetadata.b(a);
            a.ac("GeographicContourLineSeries", () => new GeographicContourLineSeriesDescription());
            a.ab("GeographicContourLineSeries", GeographicContourLineSeriesDescriptionMetadata.a);
        }
    }
    GeographicContourLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicContourLineSeriesDescriptionMetadata, 'GeographicContourLineSeriesDescriptionMetadata');
    GeographicContourLineSeriesDescriptionMetadata.a = null;
    return GeographicContourLineSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GeographicContourLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ValueBrushScaleDescriptionMetadata } from "./ValueBrushScaleDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { GeographicXYTriangulatingSeriesDescriptionMetadata } from "./GeographicXYTriangulatingSeriesDescriptionMetadata";
import { GeographicContourLineSeriesDescription } from "./GeographicContourLineSeriesDescription";
/**
 * @hidden
 */
export let GeographicContourLineSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicContourLineSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicContourLineSeriesDescriptionMetadata.a == null) {
                GeographicContourLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicContourLineSeriesDescriptionMetadata.c(GeographicContourLineSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicContourLineSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicContourLineSeriesDescriptionMetadata.a);
            ValueBrushScaleDescriptionMetadata.d(a);
            ContourValueResolverDescriptionMetadata.d(a);
            TriangulationStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(a);
            a.item("ValueMemberPath", "String");
            a.item("FillScale", "ExportedType:ValueBrushScale");
            a.item("ActualFillScale", "ExportedType:ValueBrushScale");
            a.item("ValueResolver", "ExportedType:ContourValueResolver");
            a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
        }
        static d(a) {
            GeographicContourLineSeriesDescriptionMetadata.b(a);
            a.ae("GeographicContourLineSeries", () => new GeographicContourLineSeriesDescription());
            a.ad("GeographicContourLineSeries", GeographicContourLineSeriesDescriptionMetadata.a);
        }
    }
    GeographicContourLineSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicContourLineSeriesDescriptionMetadata, 'GeographicContourLineSeriesDescriptionMetadata');
    GeographicContourLineSeriesDescriptionMetadata.a = null;
    return GeographicContourLineSeriesDescriptionMetadata;
})();
